Intro
=========================
transitionMatrix is a Python powered library for the statistical analysis and visualization of state transition 
phenomena. It can be used to analyze any dataset that captures timestamped transitions in a discrete state space. 
Use cases include credit rating transitions, system state event logs etc. 

You can use transitionMatrix to

- Estimate transition matrices from historical event data using a variety of estimators
- Visualize event data and transition matrices
- Manipulate transition matrices (generators, comparisons etc.)
- Provide standardized data sets for testing
- Model transitions using threshold processes

Key Information
================

* Author: [Open Risk](http://www.openriskmanagement.com)
* License: Apache 2.0
* Code Documentation: [Read The Docs](https://transitionmatrix.readthedocs.io/en/latest/index.html)
* Mathematical Documentation: [Open Risk Manual](https://www.openriskmanual.org/wiki/Transition_Matrix)
* Development website: [Github](https://github.com/open-risk/transitionMatrix)
* Production instance [OpenCPM](https://www.opencpm.com)
* Gitter Room: [Open Risk Lobby](https://gitter.im/open-risk/Lobby)

**NB: transitionMatrix is still in active development. If you encounter issues please raise them in our
github repository**

Support and Training
=========================

* The Open Risk Academy has free courses demonstrating the use of the library. The current list is: 
    * [Analysis of Credit Migration using Python TransitionMatrix](https://www.openriskacademy.com/course/view.php?id=38)
* Commercial Support for transitionMatrix is provided as part of OpenCPM

</pre>


Examples
========

The [code documentation](https://transitionmatrix.readthedocs.io/en/latest/index.html) includes a 
large number of examples, jupyter notebooks and more. 


Plotting individual transition trajectories

![image](examples/single_entity.png)

Sampling transition data

![image](examples/sampled_histories.png)

Estimation of transition matrices using cohort methods

![image](examples/estimation.png)

Estimation of transition matrices using duration methods

![image](examples/transition_probabilities.png)

Visualization of a transition matrix

![image](examples/TransitionMatrix.png)

Generating stochastic process transition thresholds

![image](examples/Thresholds.png)

Computation and Visualization of Credit Curves

![image](examples/credit_curves.png)

